mmseq2counts <- function( mmseq_files = grep("gene|amalgamated", dir( pattern="\\.mmseq$" ), value=TRUE, invert=TRUE),
		hits_files = dir( pattern="hits" ), sample_names = sub("\\.mmseq","", mmseq_files) ) {
	
	cat( "Using\n\tmmseq files:", mmseq_files, "\n\thits files:", hits_files, "\n\tsample names:", sample_names, "\n" )
	if( length(mmseq_files) == 0 || length(hits_files) == 0 ) {
		cat( "ERROR:\n\tplease define mmseq and hits files.\n" )
		return(NULL)
	}
	
	# read in mmseq data
	data = list()
	cat( "Reading mmseq output file\n" )
	for( i in 1:length(mmseq_files) ) {
		cat( "\t", mmseq_files[i], "\n" )
		dat = read.table( mmseq_files[i], header=TRUE, stringsAsFactors=FALSE )
		data[[sample_names[i]]] = dat$log_mu_gibbs
		names(data[[sample_names[i]]]) = dat[,grepl("id", colnames(dat))]
	}
	
	cat( "Sorting transcripts\n" )
	allnames = sort(unique(unlist(lapply( data, function(x) names(x) ))))
	tab = data.frame( row.names=allnames )
	for( e in data ) {
		tab = cbind(tab, rep(NA, nrow(tab)))
		tab[match(names(e), allnames),ncol(tab)] = e
	}
	colnames(tab) = names(data)
	
	# read in total reads 
	n_reads = c()
	lengths = list()
	cat( "Counting reads and getting transcript lengths for\n" )
	for( i in 1:length(hits_files) ) {
		cat( "\t", hits_files[i] )
		cmd = paste("grep \">\"", hits_files[i], "| wc -l")
		n_reads = c(n_reads, as.numeric(system(cmd, intern=T)) )
		cat( "\n\t\tfound", n_reads[length(n_reads)], "aligned reads\n" )
		cmd = paste( "grep '^@TranscriptMetaData'", hits_files[i], "| awk '{print $2 \" \" $3}'" )
		tt = strsplit( system(cmd, intern=T), split=" " )
		lengths[[sample_names[i]]] = as.numeric(sapply(tt, function(x) x[2] ) )
		names(lengths[[sample_names[i]]]) = sapply(tt, function(x) x[1] )  
	}
	names(n_reads) = sample_names
	
	cat( "Sorting lengths\n" )
	allnames = sort(unique(unlist(lapply( lengths, function(x) names(x) ))))
	t_lengths = data.frame( row.names=allnames )
	for( e in lengths ) {
		t_lengths = cbind(t_lengths, rep(NA, nrow(t_lengths)))
		t_lengths[match(names(e), allnames),ncol(t_lengths)] = e
	}
	colnames(t_lengths) = names(data)
	t_lengths = t_lengths[match(rownames(tab),rownames(t_lengths)),]
	
	# un-log the estimates 
	cat( "Unlogging and unstandardising the estimates\n" )
	tab = exp(1)^(tab)
	tab[is.na(tab)] = 0 # the ones that had no expression in MMSEQ
	
	# multiply by library size
	utab = sapply( colnames(tab), function(x) {	tab[,x]*n_reads[x] })
	rownames(utab)=rownames(tab)
	
	# multiply by transcript length and divide by 10^9
	utab = sapply( colnames(tab), function(x) { utab[,x] = (utab[,x]*t_lengths[,x])/(1e3*1e6) } )
	
	return(utab)
}